@@ -1,14 +1,13 @@
-from django.test import TestCase
-
+from django_theme.tests.case import ThemeBaseCase
 from django_theme.libs.code import Code
 
 from .theme import ThemeCase
 
 
-class ThemeFunctionalTest(TestCase):
+class ThemeFunctionalTest(ThemeBaseCase):
     def setUp(self) -> None:
-        self.api_theme_url = "/api/system/theme"
         ThemeCase()
+        super().setUp()
 
     def assertResponse(self) -> dict:
         response = self.client.get(path=self.api_theme_url)
