@@ -4,9 +4,12 @@ from ..models import Theme
 
 
 class ThemeCase:
-    def __init__(self):
+    """
+    create a sample theme
+    """
+
+    def __init__(self, corporate_logo_path="fixtures/test_file/image.jpg", tab_logo_path="fixtures/test_file/AAV43679.png"):
         self.theme = {
-            "theme_id": "1",
             "title": "天和双利",
             "theme_color": "#e60000",
             "aux_color": "#666666",
@@ -14,10 +17,10 @@ class ThemeCase:
         self.theme_object = self.create_theme()
 
         self.theme_object.corporate_logo.save(
-            "logo.jpg", File(open("fixtures/test_file/image.jpg", "rb"))
+            "logo.jpg", File(open(corporate_logo_path, "rb"))
         )
         self.theme_object.tab_logo.save(
-            "tab_logo.png", File(open("fixtures/test_file/AAV43679.png", "rb"))
+            "tab_logo.png", File(open(tab_logo_path, "rb"))
         )
 
     def attach_file(self):
